@@ -1,15 +1,15 @@
-// $Id: parser.cpp,v 1.14 2001/09/14 05:31:34 ericb Exp $
+// $Id: parser.cpp,v 1.28 2004/03/25 13:32:28 ericb Exp $
 //
 // This software is subject to the terms of the IBM Jikes Compiler
 // License Agreement available at the following URL:
 // http://ibm.com/developerworks/opensource/jikes.
-// Copyright (C) 1996, 1998, 1999, 2000, 2001 International Business
-// Machines Corporation and others.  All Rights Reserved.
+// Copyright (C) 1996, 2004 IBM Corporation and others.  All Rights Reserved.
 // You must accept the terms of that agreement to use this software.
 //
 
 #include "parser.h"
 #include "ast.h"
+#include "stream.h"
 
 #ifdef HAVE_JIKES_NAMESPACE
 namespace Jikes { // Open namespace Jikes block
@@ -23,24 +23,28 @@ void Parser::ReallocateStacks()
 
     assert(stack_length <= SHRT_MAX);
 
-    int *old_stack = stack;
-    stack = (int *) memmove(new int[stack_length], stack, old_stack_length * sizeof(int));
+    int* old_stack = stack;
+    stack = (int*) memcpy(new int[stack_length], stack,
+                          old_stack_length * sizeof(int));
     delete [] old_stack;
 
-    Location *old_location_stack = location_stack;
-    location_stack = (Location *) memmove(new Location[stack_length], location_stack, old_stack_length * sizeof(Location));
+    Location* old_location_stack = location_stack;
+    location_stack = (Location*) memcpy(new Location[stack_length],
+                                        location_stack,
+                                        old_stack_length * sizeof(Location));
     delete [] old_location_stack;
 
-    Ast **old_parse_stack = parse_stack;
-    parse_stack = (Ast **) memmove(new Ast *[stack_length], parse_stack, old_stack_length * sizeof(Ast *));
+    Ast** old_parse_stack = parse_stack;
+    parse_stack = (Ast**) memcpy(new Ast*[stack_length], parse_stack,
+                                 old_stack_length * sizeof(Ast*));
     delete [] old_parse_stack;
-    parse_stack[old_stack_length] = NULL; // the first time through, we initialize parse_stack[0] to NULL !!!
+    // The first time through, we initialize parse_stack[0] to NULL.
+    parse_stack[old_stack_length] = NULL;
 
-    int *old_temp_stack = temp_stack;
-    temp_stack = (int *) memmove(new int[stack_length], temp_stack, old_stack_length * sizeof(int));
+    int* old_temp_stack = temp_stack;
+    temp_stack = (int*) memcpy(new int[stack_length], temp_stack,
+                               old_stack_length * sizeof(int));
     delete [] old_temp_stack;
-
-    return;
 }
 
 
@@ -59,45 +63,57 @@ AstListNode *Parser::AllocateListNode()
 }
 
 
-void Parser::FreeCircularList(AstListNode *tail)
+void Parser::FreeCircularList(AstListNode* tail)
 {
-    AstListNode *root = tail -> next;
-    tail -> next = free_list_nodes;
-    free_list_nodes = root;
-
-    return;
+    if (tail)
+    {
+        AstListNode* root = tail -> next;
+        tail -> next = free_list_nodes;
+        free_list_nodes = root;
+    }
 }
 
 
-AstPackageDeclaration *Parser::PackageHeaderParse(LexStream *lex_stream_, StoragePool *ast_pool_)
+AstPackageDeclaration* Parser::PackageHeaderParse(LexStream* lex_stream_,
+                                                  StoragePool* ast_pool_)
 {
-    AstPackageDeclaration *package_declaration = NULL;
-
+    AstPackageDeclaration* package_declaration = NULL;
     lex_stream_ -> Reset();
 
-    if (lex_stream_ -> Kind(lex_stream_ -> Peek()) == TK_package)
+    if (lex_stream_ -> PackageToken())
     {
         ast_pool = ast_pool_;
+        list_node_pool = new StoragePool(lex_stream_ -> NumTokens());
+        free_list_nodes = NULL;
 
         parse_package_header_only = true;
-        end_token = LexStream::LEX_INFINITY; // We are parsing the whole input and not just a segment.
+        // We are parsing the whole input and not just a segment.
+        end_token = LexStream::LEX_INFINITY;
         lex_stream = lex_stream_;
         Ast *ast = HeaderParse();
         parse_package_header_only = false;
 
         if (ast)
         {
-            AstCompilationUnit *compilation_unit = ast -> CompilationUnitCast();
-            if (compilation_unit && (! compilation_unit -> BadCompilationUnitCast()))
-                package_declaration = compilation_unit -> package_declaration_opt;
+            AstCompilationUnit *compilation_unit =
+                ast -> CompilationUnitCast();
+            if (compilation_unit &&
+                ! compilation_unit -> BadCompilationUnitCast())
+            {
+                package_declaration =
+                    compilation_unit -> package_declaration_opt;
+            }
         }
+
+        delete list_node_pool;
     }
 
     return package_declaration;
 }
 
 
-AstCompilationUnit *Parser::HeaderParse(LexStream *lex_stream_, StoragePool *ast_pool_)
+AstCompilationUnit* Parser::HeaderParse(LexStream* lex_stream_,
+                                        StoragePool* ast_pool_)
 {
     lex_stream_ -> Reset();
 
@@ -108,7 +124,8 @@ AstCompilationUnit *Parser::HeaderParse(LexStream *lex_stream_, StoragePool *ast
     AstCompilationUnit *compilation_unit = NULL;
 
     parse_header_only = true;
-    end_token = LexStream::LEX_INFINITY; // We are parsing the whole input and not just a segment.
+    // We are parsing the whole input and not just a segment.
+    end_token = LexStream::LEX_INFINITY;
     lex_stream = lex_stream_;
     Ast *ast = HeaderParse();
     parse_header_only = false;
@@ -116,20 +133,18 @@ AstCompilationUnit *Parser::HeaderParse(LexStream *lex_stream_, StoragePool *ast
     if (ast)
     {
         compilation_unit = ast -> CompilationUnitCast();
-        if (compilation_unit && (! compilation_unit -> BadCompilationUnitCast()))
+        if (compilation_unit &&
+            ! compilation_unit -> BadCompilationUnitCast())
         {
             if (compilation_unit -> NumTypeDeclarations() == 0)
-                compilation_unit -> kind = Ast::EMPTY_COMPILATION;
+                compilation_unit -> MarkEmpty();
         }
-// STG:
-//      else delete ast;
-//
     }
 
     //
-    // If we succesfully parsed a compilation unit, allocate a storage pool for it.
-    // Subtract the amount of space that's already been allocated for the headers
-    // from the estimate for the bodies.
+    // If we succesfully parsed a compilation unit, allocate a storage pool
+    // for it. Subtract the amount of space that's already been allocated for
+    // the headers from the estimate for the bodies.
     //
     if (compilation_unit)
          compilation_unit -> ast_pool = body_pool;
@@ -141,7 +156,7 @@ AstCompilationUnit *Parser::HeaderParse(LexStream *lex_stream_, StoragePool *ast
 }
 
 
-Ast *Parser::HeaderParse()
+Ast* Parser::HeaderParse()
 {
     TokenObject curtok = lex_stream -> Gettoken();
     int act = START_STATE,
@@ -155,7 +170,7 @@ Ast *Parser::HeaderParse()
     //
     // Process a terminal
     //
-    for (;;)
+    while (true)
     {
         if (++state_stack_top >= stack_length)
             ReallocateStacks();
@@ -169,8 +184,6 @@ Ast *Parser::HeaderParse()
             state_stack_top--; // make reduction look like a shift-reduce
         else if (act > ERROR_ACTION)
         {
-// STG:
-//            token_action(curtok);
             curtok = lex_stream -> Gettoken();
             current_kind = lex_stream -> Kind(curtok);
 
@@ -178,8 +191,6 @@ Ast *Parser::HeaderParse()
         }
         else if (act < ACCEPT_ACTION)
         {
-// STG:
-//            token_action(curtok);
             curtok = lex_stream -> Gettoken();
             current_kind = lex_stream -> Kind(curtok);
 
@@ -201,26 +212,22 @@ Ast *Parser::HeaderParse()
     if (act == ERROR_ACTION)
     {
         //
-        // If any error is found in a package declaration, do not try to repair it.
+        // If any error is found in a package declaration, do not try to
+        // repair it.
         //
         if (! parse_package_header_only)
             RepairParse(curtok);
 
         if (parse_stack[0] && parse_stack[0] -> CompilationUnitCast())
-            parse_stack[0] -> kind = Ast::BAD_COMPILATION;
-        else
-        {
-// STG:
-//            delete parse_stack[0];
-            parse_stack[0] = NULL;
-        }
+            ((AstCompilationUnit*) parse_stack[0]) -> MarkBad();
+        else parse_stack[0] = NULL;
     }
 
     return parse_stack[0];
 }
 
 
-bool Parser::BodyParse(LexStream *lex_stream_, AstClassBody *class_body)
+bool Parser::BodyParse(LexStream* lex_stream_, AstClassBody* class_body)
 {
     assert(class_body -> UnparsedClassBodyCast());
 
@@ -230,232 +237,120 @@ bool Parser::BodyParse(LexStream *lex_stream_, AstClassBody *class_body)
     list_node_pool = new StoragePool(lex_stream_ -> NumTokens());
     free_list_nodes = NULL;
 
-    bool no_errors_detected = Body(class_body);
+    bool success = Body(class_body);
 
     delete list_node_pool; // free the pool of list nodes
 
-    class_body -> mark_parsed();
+    class_body -> MarkParsed();
 
-    return no_errors_detected;
+    return success;
 }
 
 
-bool Parser::Body(AstClassBody *class_body)
+bool Parser::Body(AstClassBody* class_body)
 {
-    bool no_errors_detected = true;
+    bool errors_detected = false;
+    unsigned i;
 
-    for (int i = 0; i < class_body -> NumConstructors(); i++)
+    for (i = 0; i < class_body -> NumConstructors(); i++)
     {
-        AstConstructorDeclaration *constructor_decl = class_body -> Constructor(i);
+        AstConstructorDeclaration* constructor_decl =
+            class_body -> Constructor(i);
 
         if (constructor_decl -> constructor_symbol)
         {
-            AstConstructorBlock *block = constructor_decl -> constructor_body;
+            AstMethodBody* block = constructor_decl -> constructor_body;
             end_token = block -> right_brace_token; // last token in the body
 
-            AstStatement *new_body = (AstStatement *) ParseSegment(block -> left_brace_token);
+            AstMethodBody* new_body = ParseSegment(block -> left_brace_token);
 
             if (! new_body)
-                no_errors_detected = false;
-            else
-            {
-                AstConstructorBlock *new_block = new_body -> ConstructorBlockCast();
-
-                if (! new_block)
-                {
-                    new_block                                        = ast_pool -> GenConstructorBlock();
-                    new_block -> left_brace_token                    = new_body -> LeftToken();
-                    new_block -> explicit_constructor_invocation_opt = NULL;
-                    new_block -> block                               = (AstBlock *) new_body;
-                    new_block -> right_brace_token                   = new_body -> RightToken();
-                }
-// STG:
-//                delete block; // destroy old empty block
-//
-                constructor_decl -> constructor_body = new_block;
-            }
+                errors_detected = true;
+            else constructor_decl -> constructor_body = new_body;
         }
     }
 
-    for (int j = 0; j < class_body -> NumMethods(); j++)
+    for (i = 0; i < class_body -> NumMethods(); i++)
     {
-        AstMethodDeclaration *method_decl = class_body -> Method(j);
-
-        if (method_decl -> method_symbol)
+        AstMethodDeclaration* method_decl = class_body -> Method(i);
+        if (method_decl -> method_symbol && method_decl -> method_body_opt)
         {
-            AstBlock *block = method_decl -> method_body -> BlockCast();
-
-            if (block)
-            {
-                end_token = block -> right_brace_token; // last token in the body
-                AstStatement *new_block = (AstStatement *) ParseSegment(block -> left_brace_token);
-
-                if (! new_block) // a bad block ?
-                    no_errors_detected = false;
-                else
-                {
-                    //
-                    // The block associated with the method may syntactically be either a
-                    // block or a constructor block. If it is a block, nest it inside the
-                    // initial block. If it is a constructor block, replace the initial block
-                    // by the constructor block.
-                    //
-                    if (new_block -> BlockCast())
-                        block -> AddStatement(new_block);
-                    else
-                    {
-                        method_decl -> method_body = new_block;
-// STG:
-//                        delete block; // destroy old empty block
-                    }
-                }
-            }
+            AstMethodBody* block = method_decl -> method_body_opt;
+            end_token = block -> right_brace_token;
+            AstMethodBody* new_block = ParseSegment(block -> left_brace_token);
+            if (! new_block) // a bad block ?
+                errors_detected = true;
+            else method_decl -> method_body_opt = new_block;
         }
     }
 
-    for (int k = 0; k < class_body -> NumNestedClasses(); k++)
-        no_errors_detected = no_errors_detected && Body(class_body -> NestedClass(k) -> class_body);
-
-    for (int l = 0; l < class_body -> NumNestedInterfaces(); l++)
-        no_errors_detected = no_errors_detected && Body(class_body -> NestedInterface(l));
-
-    return no_errors_detected;
-}
-
-bool Parser::BodyParse(LexStream *lex_stream_, AstInterfaceDeclaration *interface_declaration)
-{
-    assert(interface_declaration -> UnparsedInterfaceBodyCast());
-
-    lex_stream = lex_stream_;
-    ast_pool = interface_declaration -> pool;
-    body_pool = interface_declaration -> pool;
-    list_node_pool = new StoragePool(lex_stream_ -> NumTokens());
-    free_list_nodes = NULL;
-
-    bool no_errors_detected = Body(interface_declaration);
-
-    delete list_node_pool; // free the pool of list nodes
-
-    interface_declaration -> mark_parsed();
-
-    return no_errors_detected;
+    for (i = 0; i < class_body -> NumNestedClasses(); i++)
+        errors_detected = errors_detected ||
+            ! Body(class_body -> NestedClass(i) -> class_body);
+    for (i = 0; i < class_body -> NumNestedInterfaces(); i++)
+        errors_detected = errors_detected ||
+            ! Body(class_body -> NestedInterface(i) -> class_body);
+    return ! errors_detected;
 }
 
 
-bool Parser::Body(AstInterfaceDeclaration *interface_declaration)
+bool Parser::InitializerParse(LexStream* stream, AstClassBody* class_body)
 {
-    bool no_errors_detected = true;
-
-    for (int k = 0; k < interface_declaration -> NumNestedClasses(); k++)
-        no_errors_detected = no_errors_detected && Body(interface_declaration -> NestedClass(k) -> class_body);
-
-    for (int l = 0; l < interface_declaration -> NumNestedInterfaces(); l++)
-        no_errors_detected = no_errors_detected && Body(interface_declaration -> NestedInterface(l));
-
-    return no_errors_detected;
-}
-
-
-bool Parser::InitializerParse(LexStream *lex_stream_, AstClassBody *class_body)
-{
-    lex_stream = lex_stream_;
+    lex_stream = stream;
     ast_pool = class_body -> pool;
     body_pool = class_body -> pool;
-    list_node_pool = new StoragePool(lex_stream_ -> NumTokens());
+    list_node_pool = new StoragePool(stream -> NumTokens());
     free_list_nodes = NULL;
 
-    bool no_errors_detected = Initializer(class_body);
+    bool success = Initializer(class_body);
 
     delete list_node_pool; // free the pool of list nodes
-
-    return no_errors_detected;
+    return success;
 }
 
 
-bool Parser::InitializerParse(LexStream *lex_stream_, AstInterfaceDeclaration *interface_declaration)
+bool Parser::Initializer(AstClassBody* class_body)
 {
-    lex_stream = lex_stream_;
-    ast_pool = interface_declaration -> pool;
-    body_pool = interface_declaration -> pool;
-    list_node_pool = new StoragePool(lex_stream_ -> NumTokens());
-    free_list_nodes = NULL;
+    bool errors_detected = false;
+    unsigned i;
 
-    bool no_errors_detected = Initializer(interface_declaration);
-
-    delete list_node_pool; // free the pool of list nodes
-
-    return no_errors_detected;
-}
-
-
-bool Parser::Initializer(AstClassBody *class_body)
-{
-    bool no_errors_detected = true;
-
-    for (int i = 0; i < class_body -> NumStaticInitializers(); i++)
+    for (i = 0; i < class_body -> NumStaticInitializers(); i++)
     {
-         AstBlock *block = class_body -> StaticInitializer(i) -> block;
+         AstMethodBody* block = class_body -> StaticInitializer(i) -> block;
          end_token = block -> right_brace_token; // last token in the body
-         class_body -> StaticInitializer(i) -> block = (AstBlock *) ParseSegment(block -> left_brace_token);
-
+         class_body -> StaticInitializer(i) -> block =
+             ParseSegment(block -> left_brace_token);
         if (! class_body -> StaticInitializer(i) -> block)
         {
-            no_errors_detected = false;
-            class_body -> StaticInitializer(i) -> block = block; // restore old empty block
+            errors_detected = true;
+            // Restore old empty block.
+            class_body -> StaticInitializer(i) -> block = block;
         }
-// STG:
-//      else
-//      {
-//          delete block; // destroy old empty block
-//      }
     }
-
-    for (int j = 0; j < class_body -> NumBlocks(); j++)
+    for (i = 0; i < class_body -> NumInstanceInitializers(); i++)
     {
-         AstBlock *block = class_body -> Block(j);
-         end_token = block -> right_brace_token; // last token in the body
-         class_body -> Block(j) = (AstBlock *) ParseSegment(block -> left_brace_token);
-
-        if (! class_body -> Block(j))
+        AstMethodBody* block = class_body -> InstanceInitializer(i) -> block;
+        end_token = block -> right_brace_token; // last token in the body
+        class_body -> InstanceInitializer(i) -> block =
+            ParseSegment(block -> left_brace_token);
+        if (! class_body -> InstanceInitializer(i) -> block)
         {
-            no_errors_detected = false;
-            class_body -> Block(j) = block; // restore old empty block
+            errors_detected = true;
+            // Restore old empty block.
+            class_body -> InstanceInitializer(i) -> block = block;
         }
-//
-// STG: if we ever go back to a new/free model of allocating Ast nodes
-// This loop needs to be rewritten as otherwise, the new block allocated
-// here would cause a memory leak since the class_body_declarations list
-// is unaware of it. The solution is to iterate over the class_body_declarations
-// list in order to locate the old block, free it and update the class_body_declarations
-// list to point to the new block.
-//
     }
-
-    for (int k = 0; k < class_body -> NumNestedClasses(); k++)
-        no_errors_detected = no_errors_detected && Initializer(class_body -> NestedClass(k) -> class_body);
-
-    for (int l = 0; l < class_body -> NumNestedInterfaces(); l++)
-        no_errors_detected = no_errors_detected && Initializer(class_body -> NestedInterface(l));
-
-    return no_errors_detected;
+    for (i = 0; i < class_body -> NumNestedClasses(); i++)
+        errors_detected = errors_detected ||
+            ! Initializer(class_body -> NestedClass(i) -> class_body);
+    for (i = 0; i < class_body -> NumNestedInterfaces(); i++)
+        errors_detected = errors_detected ||
+            ! Initializer(class_body -> NestedInterface(i) -> class_body);
+    return ! errors_detected;
 }
 
 
-bool Parser::Initializer(AstInterfaceDeclaration *interface_declaration)
-{
-    bool no_errors_detected = true;
-
-    for (int k = 0; k < interface_declaration -> NumNestedClasses(); k++)
-        no_errors_detected = no_errors_detected && Initializer(interface_declaration -> NestedClass(k) -> class_body);
-
-    for (int l = 0; l < interface_declaration -> NumNestedInterfaces(); l++)
-        no_errors_detected = no_errors_detected && Initializer(interface_declaration -> NestedInterface(l));
-
-    return no_errors_detected;
-}
-
-
-Ast *Parser::ParseSegment(TokenObject start_token)
+AstMethodBody* Parser::ParseSegment(TokenObject start_token)
 {
     //
     // The next call to Gettoken will return the start_token.
@@ -475,7 +370,7 @@ Ast *Parser::ParseSegment(TokenObject start_token)
     //
     // Process a terminal
     //
-    for (;;)
+    while (true)
     {
         if (++state_stack_top >= stack_length)
             ReallocateStacks();
@@ -489,8 +384,6 @@ Ast *Parser::ParseSegment(TokenObject start_token)
             state_stack_top--; // make reduction look like a shift-reduce
         else if (act > ERROR_ACTION)
         {
-// STG:
-//            token_action(curtok);
             curtok = lex_stream -> Gettoken(end_token);
             current_kind = lex_stream -> Kind(curtok);
 
@@ -498,8 +391,6 @@ Ast *Parser::ParseSegment(TokenObject start_token)
         }
         else if (act < ACCEPT_ACTION)
         {
-// STG:
-//            token_action(curtok);
             curtok = lex_stream -> Gettoken(end_token);
             current_kind = lex_stream -> Kind(curtok);
 
@@ -522,12 +413,10 @@ Ast *Parser::ParseSegment(TokenObject start_token)
     {
         RepairParse(curtok);
 
-// STG:
-//        delete parse_stack[0];
         parse_stack[0] = NULL;
     }
 
-    return parse_stack[0];
+    return DYNAMIC_CAST<AstMethodBody *> (parse_stack[0]);
 }
 
 
@@ -536,7 +425,7 @@ void Parser::RepairParse(TokenObject curtok)
     //
     // Repair an error
     //
-    for (;;)
+    while (true)
     {
         //
         // Pop state stack up to first state that had an
@@ -545,14 +434,9 @@ void Parser::RepairParse(TokenObject curtok)
         // caused by the error token.
         //
         int k;
-        for (k = state_stack_top - 1; k >= 0 && location_stack[k] == Loc(curtok); k--)
-             ;
+        for (k = state_stack_top - 1;
+             k >= 0 && location_stack[k] == Loc(curtok); k--);
         k++;
-// STG:
-//        for (int i = k; i < state_stack_top; i++)
-//        {
-//            delete parse_stack[i];
-//        }
 
         state_stack_top = k;
 
@@ -565,7 +449,7 @@ void Parser::RepairParse(TokenObject curtok)
         //
         // Process a terminal
         //
-        for (;;)
+        while (true)
         {
             if (++state_stack_top >= stack_length)
                  ReallocateStacks();
@@ -579,8 +463,6 @@ void Parser::RepairParse(TokenObject curtok)
                 state_stack_top--; // make reduction look like a shift-reduce
             else if (act > ERROR_ACTION)
             {
-// STG:
-//                token_action(curtok);
                 curtok = lex_stream -> Gettoken(end_token);
                 current_kind = lex_stream -> Kind(curtok);
 
@@ -588,8 +470,6 @@ void Parser::RepairParse(TokenObject curtok)
             }
             else if (act < ACCEPT_ACTION)
             {
-// STG:
-//                token_action(curtok);
                 curtok = lex_stream -> Gettoken(end_token);
                 current_kind = lex_stream -> Kind(curtok);
 
@@ -601,7 +481,9 @@ void Parser::RepairParse(TokenObject curtok)
             //
             else if (act == ACCEPT_ACTION)
                  return;
-            else break; // loop around and keep trying until something is accepted.
+            else
+                // loop around and keep trying until something is accepted.
+                break;
 
             //
             // Process a nonterminal
@@ -614,8 +496,6 @@ void Parser::RepairParse(TokenObject curtok)
             } while (act <= NUM_RULES);
         } /* process_terminal */
     }
-
-    return;
 }
 
 
@@ -642,7 +522,8 @@ void Parser::ErrorRepair(TokenObject error_token)
 
         int last_index;
         for (last_index = MAX_DISTANCE - 1;
-             last_index >= 1 && lex_stream -> Kind(buffer[last_index]) == EOFT_SYMBOL;
+             last_index >= 1 &&
+                 lex_stream -> Kind(buffer[last_index]) == EOFT_SYMBOL;
              last_index--);
         last_index++;
 
@@ -650,16 +531,8 @@ void Parser::ErrorRepair(TokenObject error_token)
         error_token = buffer[MAX_DISTANCE - MIN_DISTANCE + 2];
     } while (repair.code == 0);
 
-// STG:
-//    for (int i = repair.stack_position; i < state_stack_top; i++)
-//    {
-//        delete parse_stack[i];
-//    }
-
     state_stack_top = repair.stack_position;
     lex_stream -> Reset(buffer[repair.buffer_position]);
-
-    return;
 }
 
 
@@ -674,15 +547,19 @@ SecondaryRepairInfo Parser::ErrorSurgery
     int stack_deletions = 0;
     Location  previous_loc = Loc(buffer[2]);
 
-    for (int top = stack_top; top >= 0 && repair.num_deletions >= stack_deletions; top--)
+    for (int top = stack_top;
+         top >= 0 && repair.num_deletions >= stack_deletions; top--)
     {
         if (location_stack[top] < previous_loc)
             stack_deletions++;
         previous_loc = location_stack[top];
 
-        for (int i = 1; i <= last_index && repair.num_deletions >= (stack_deletions + i - 1); i++)
+        for (int i = 1;
+             i <= last_index &&
+                 repair.num_deletions >= (stack_deletions + i - 1); i++)
         {
-            int j = ParseCheck(stck, top, lex_stream -> Kind(buffer[i]), i + 1);
+            int j = ParseCheck(stck, top, lex_stream -> Kind(buffer[i]),
+                               i + 1);
 
             if ((j - i + 1) > MIN_DISTANCE)
             {
@@ -709,7 +586,8 @@ SecondaryRepairInfo Parser::ErrorSurgery
 /* been consumed, or an error is encountered. Return the number  */
 /* of tokens that were expended before the parse blocked.        */
 /*****************************************************************/
-int Parser::ParseCheck(int stck[], int stack_top, int first_token, int buffer_position)
+int Parser::ParseCheck(int stck[], int stack_top, int first_token,
+                       int buffer_position)
 {
     int max_pos,
         indx,
@@ -743,7 +621,8 @@ int Parser::ParseCheck(int stck[], int stack_top, int first_token, int buffer_po
         lex_stream -> Reset(buffer[buffer_position]);
     }
 
-    process_terminal: for (;;)
+ process_terminal:
+    while (true)
     {
         if (++temp_stack_top >= stack_length)  /* Stack overflow!!! */
             return indx;
